#if defined (HAVE_CONFIG_H)
#  include "config.h"
#endif
/****************************************************************************
** Meta object code from reading C++ file 'dialog.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.4)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "/pub/devel/octave/octave-6.4.0-1.i686/src/octave-6.4.0/libgui/src/dialog.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'dialog.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_octave__QUIWidgetCreator_t {
    QByteArrayData data[42];
    char stringdata0[499];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_octave__QUIWidgetCreator_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_octave__QUIWidgetCreator_t qt_meta_stringdata_octave__QUIWidgetCreator = {
    {
QT_MOC_LITERAL(0, 0, 24), // "octave::QUIWidgetCreator"
QT_MOC_LITERAL(1, 25, 13), // "create_dialog"
QT_MOC_LITERAL(2, 39, 0), // ""
QT_MOC_LITERAL(3, 40, 15), // "create_listview"
QT_MOC_LITERAL(4, 56, 8), // "QIntList"
QT_MOC_LITERAL(5, 65, 18), // "create_inputlayout"
QT_MOC_LITERAL(6, 84, 10), // "QFloatList"
QT_MOC_LITERAL(7, 95, 17), // "create_filedialog"
QT_MOC_LITERAL(8, 113, 7), // "filters"
QT_MOC_LITERAL(9, 121, 5), // "title"
QT_MOC_LITERAL(10, 127, 8), // "filename"
QT_MOC_LITERAL(11, 136, 7), // "dirname"
QT_MOC_LITERAL(12, 144, 9), // "multimode"
QT_MOC_LITERAL(13, 154, 20), // "handle_create_dialog"
QT_MOC_LITERAL(14, 175, 7), // "message"
QT_MOC_LITERAL(15, 183, 4), // "icon"
QT_MOC_LITERAL(16, 188, 6), // "button"
QT_MOC_LITERAL(17, 195, 9), // "defbutton"
QT_MOC_LITERAL(18, 205, 4), // "role"
QT_MOC_LITERAL(19, 210, 21), // "dialog_button_clicked"
QT_MOC_LITERAL(20, 232, 16), // "QAbstractButton*"
QT_MOC_LITERAL(21, 249, 22), // "handle_create_listview"
QT_MOC_LITERAL(22, 272, 4), // "list"
QT_MOC_LITERAL(23, 277, 4), // "mode"
QT_MOC_LITERAL(24, 282, 5), // "width"
QT_MOC_LITERAL(25, 288, 6), // "height"
QT_MOC_LITERAL(26, 295, 7), // "initial"
QT_MOC_LITERAL(27, 303, 4), // "name"
QT_MOC_LITERAL(28, 308, 6), // "prompt"
QT_MOC_LITERAL(29, 315, 9), // "ok_string"
QT_MOC_LITERAL(30, 325, 13), // "cancel_string"
QT_MOC_LITERAL(31, 339, 20), // "list_select_finished"
QT_MOC_LITERAL(32, 360, 8), // "selected"
QT_MOC_LITERAL(33, 369, 14), // "button_pressed"
QT_MOC_LITERAL(34, 384, 25), // "handle_create_inputlayout"
QT_MOC_LITERAL(35, 410, 14), // "input_finished"
QT_MOC_LITERAL(36, 425, 5), // "input"
QT_MOC_LITERAL(37, 431, 24), // "handle_create_filedialog"
QT_MOC_LITERAL(38, 456, 19), // "filedialog_finished"
QT_MOC_LITERAL(39, 476, 5), // "files"
QT_MOC_LITERAL(40, 482, 4), // "path"
QT_MOC_LITERAL(41, 487, 11) // "filterindex"

    },
    "octave::QUIWidgetCreator\0create_dialog\0"
    "\0create_listview\0QIntList\0create_inputlayout\0"
    "QFloatList\0create_filedialog\0filters\0"
    "title\0filename\0dirname\0multimode\0"
    "handle_create_dialog\0message\0icon\0"
    "button\0defbutton\0role\0dialog_button_clicked\0"
    "QAbstractButton*\0handle_create_listview\0"
    "list\0mode\0width\0height\0initial\0name\0"
    "prompt\0ok_string\0cancel_string\0"
    "list_select_finished\0selected\0"
    "button_pressed\0handle_create_inputlayout\0"
    "input_finished\0input\0handle_create_filedialog\0"
    "filedialog_finished\0files\0path\0"
    "filterindex"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_octave__QUIWidgetCreator[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
      12,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       4,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    6,   74,    2, 0x06 /* Public */,
       3,    9,   87,    2, 0x06 /* Public */,
       5,    5,  106,    2, 0x06 /* Public */,
       7,    5,  117,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
      13,    6,  128,    2, 0x0a /* Public */,
      19,    1,  141,    2, 0x0a /* Public */,
      21,    9,  144,    2, 0x0a /* Public */,
      31,    2,  163,    2, 0x0a /* Public */,
      34,    5,  168,    2, 0x0a /* Public */,
      35,    2,  179,    2, 0x0a /* Public */,
      37,    5,  184,    2, 0x0a /* Public */,
      38,    3,  195,    2, 0x0a /* Public */,

 // signals: parameters
    QMetaType::Void, QMetaType::QString, QMetaType::QString, QMetaType::QString, QMetaType::QStringList, QMetaType::QString, QMetaType::QStringList,    2,    2,    2,    2,    2,    2,
    QMetaType::Void, QMetaType::QStringList, QMetaType::QString, QMetaType::Int, QMetaType::Int, 0x80000000 | 4, QMetaType::QString, QMetaType::QStringList, QMetaType::QString, QMetaType::QString,    2,    2,    2,    2,    2,    2,    2,    2,    2,
    QMetaType::Void, QMetaType::QStringList, QMetaType::QString, 0x80000000 | 6, 0x80000000 | 6, QMetaType::QStringList,    2,    2,    2,    2,    2,
    QMetaType::Void, QMetaType::QStringList, QMetaType::QString, QMetaType::QString, QMetaType::QString, QMetaType::QString,    8,    9,   10,   11,   12,

 // slots: parameters
    QMetaType::Void, QMetaType::QString, QMetaType::QString, QMetaType::QString, QMetaType::QStringList, QMetaType::QString, QMetaType::QStringList,   14,    9,   15,   16,   17,   18,
    QMetaType::Void, 0x80000000 | 20,   16,
    QMetaType::Void, QMetaType::QStringList, QMetaType::QString, QMetaType::Int, QMetaType::Int, 0x80000000 | 4, QMetaType::QString, QMetaType::QStringList, QMetaType::QString, QMetaType::QString,   22,   23,   24,   25,   26,   27,   28,   29,   30,
    QMetaType::Void, 0x80000000 | 4, QMetaType::Int,   32,   33,
    QMetaType::Void, QMetaType::QStringList, QMetaType::QString, 0x80000000 | 6, 0x80000000 | 6, QMetaType::QStringList,    2,    2,    2,    2,    2,
    QMetaType::Void, QMetaType::QStringList, QMetaType::Int,   36,   33,
    QMetaType::Void, QMetaType::QStringList, QMetaType::QString, QMetaType::QString, QMetaType::QString, QMetaType::QString,    8,    9,   10,   11,   12,
    QMetaType::Void, QMetaType::QStringList, QMetaType::QString, QMetaType::Int,   39,   40,   41,

       0        // eod
};

void octave::QUIWidgetCreator::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        QUIWidgetCreator *_t = static_cast<QUIWidgetCreator *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->create_dialog((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2])),(*reinterpret_cast< const QString(*)>(_a[3])),(*reinterpret_cast< const QStringList(*)>(_a[4])),(*reinterpret_cast< const QString(*)>(_a[5])),(*reinterpret_cast< const QStringList(*)>(_a[6]))); break;
        case 1: _t->create_listview((*reinterpret_cast< const QStringList(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2])),(*reinterpret_cast< int(*)>(_a[3])),(*reinterpret_cast< int(*)>(_a[4])),(*reinterpret_cast< const QIntList(*)>(_a[5])),(*reinterpret_cast< const QString(*)>(_a[6])),(*reinterpret_cast< const QStringList(*)>(_a[7])),(*reinterpret_cast< const QString(*)>(_a[8])),(*reinterpret_cast< const QString(*)>(_a[9]))); break;
        case 2: _t->create_inputlayout((*reinterpret_cast< const QStringList(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2])),(*reinterpret_cast< const QFloatList(*)>(_a[3])),(*reinterpret_cast< const QFloatList(*)>(_a[4])),(*reinterpret_cast< const QStringList(*)>(_a[5]))); break;
        case 3: _t->create_filedialog((*reinterpret_cast< const QStringList(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2])),(*reinterpret_cast< const QString(*)>(_a[3])),(*reinterpret_cast< const QString(*)>(_a[4])),(*reinterpret_cast< const QString(*)>(_a[5]))); break;
        case 4: _t->handle_create_dialog((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2])),(*reinterpret_cast< const QString(*)>(_a[3])),(*reinterpret_cast< const QStringList(*)>(_a[4])),(*reinterpret_cast< const QString(*)>(_a[5])),(*reinterpret_cast< const QStringList(*)>(_a[6]))); break;
        case 5: _t->dialog_button_clicked((*reinterpret_cast< QAbstractButton*(*)>(_a[1]))); break;
        case 6: _t->handle_create_listview((*reinterpret_cast< const QStringList(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2])),(*reinterpret_cast< int(*)>(_a[3])),(*reinterpret_cast< int(*)>(_a[4])),(*reinterpret_cast< const QIntList(*)>(_a[5])),(*reinterpret_cast< const QString(*)>(_a[6])),(*reinterpret_cast< const QStringList(*)>(_a[7])),(*reinterpret_cast< const QString(*)>(_a[8])),(*reinterpret_cast< const QString(*)>(_a[9]))); break;
        case 7: _t->list_select_finished((*reinterpret_cast< const QIntList(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2]))); break;
        case 8: _t->handle_create_inputlayout((*reinterpret_cast< const QStringList(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2])),(*reinterpret_cast< const QFloatList(*)>(_a[3])),(*reinterpret_cast< const QFloatList(*)>(_a[4])),(*reinterpret_cast< const QStringList(*)>(_a[5]))); break;
        case 9: _t->input_finished((*reinterpret_cast< const QStringList(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2]))); break;
        case 10: _t->handle_create_filedialog((*reinterpret_cast< const QStringList(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2])),(*reinterpret_cast< const QString(*)>(_a[3])),(*reinterpret_cast< const QString(*)>(_a[4])),(*reinterpret_cast< const QString(*)>(_a[5]))); break;
        case 11: _t->filedialog_finished((*reinterpret_cast< const QStringList(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2])),(*reinterpret_cast< int(*)>(_a[3]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            typedef void (QUIWidgetCreator::*_t)(const QString & , const QString & , const QString & , const QStringList & , const QString & , const QStringList & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QUIWidgetCreator::create_dialog)) {
                *result = 0;
                return;
            }
        }
        {
            typedef void (QUIWidgetCreator::*_t)(const QStringList & , const QString & , int , int , const QIntList & , const QString & , const QStringList & , const QString & , const QString & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QUIWidgetCreator::create_listview)) {
                *result = 1;
                return;
            }
        }
        {
            typedef void (QUIWidgetCreator::*_t)(const QStringList & , const QString & , const QFloatList & , const QFloatList & , const QStringList & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QUIWidgetCreator::create_inputlayout)) {
                *result = 2;
                return;
            }
        }
        {
            typedef void (QUIWidgetCreator::*_t)(const QStringList & , const QString & , const QString & , const QString & , const QString & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&QUIWidgetCreator::create_filedialog)) {
                *result = 3;
                return;
            }
        }
    }
}

const QMetaObject octave::QUIWidgetCreator::staticMetaObject = {
    { &QObject::staticMetaObject, qt_meta_stringdata_octave__QUIWidgetCreator.data,
      qt_meta_data_octave__QUIWidgetCreator,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *octave::QUIWidgetCreator::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *octave::QUIWidgetCreator::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_octave__QUIWidgetCreator.stringdata0))
        return static_cast<void*>(this);
    return QObject::qt_metacast(_clname);
}

int octave::QUIWidgetCreator::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QObject::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 12)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 12;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 12)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 12;
    }
    return _id;
}

// SIGNAL 0
void octave::QUIWidgetCreator::create_dialog(const QString & _t1, const QString & _t2, const QString & _t3, const QStringList & _t4, const QString & _t5, const QStringList & _t6)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)), const_cast<void*>(reinterpret_cast<const void*>(&_t3)), const_cast<void*>(reinterpret_cast<const void*>(&_t4)), const_cast<void*>(reinterpret_cast<const void*>(&_t5)), const_cast<void*>(reinterpret_cast<const void*>(&_t6)) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 1
void octave::QUIWidgetCreator::create_listview(const QStringList & _t1, const QString & _t2, int _t3, int _t4, const QIntList & _t5, const QString & _t6, const QStringList & _t7, const QString & _t8, const QString & _t9)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)), const_cast<void*>(reinterpret_cast<const void*>(&_t3)), const_cast<void*>(reinterpret_cast<const void*>(&_t4)), const_cast<void*>(reinterpret_cast<const void*>(&_t5)), const_cast<void*>(reinterpret_cast<const void*>(&_t6)), const_cast<void*>(reinterpret_cast<const void*>(&_t7)), const_cast<void*>(reinterpret_cast<const void*>(&_t8)), const_cast<void*>(reinterpret_cast<const void*>(&_t9)) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}

// SIGNAL 2
void octave::QUIWidgetCreator::create_inputlayout(const QStringList & _t1, const QString & _t2, const QFloatList & _t3, const QFloatList & _t4, const QStringList & _t5)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)), const_cast<void*>(reinterpret_cast<const void*>(&_t3)), const_cast<void*>(reinterpret_cast<const void*>(&_t4)), const_cast<void*>(reinterpret_cast<const void*>(&_t5)) };
    QMetaObject::activate(this, &staticMetaObject, 2, _a);
}

// SIGNAL 3
void octave::QUIWidgetCreator::create_filedialog(const QStringList & _t1, const QString & _t2, const QString & _t3, const QString & _t4, const QString & _t5)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)), const_cast<void*>(reinterpret_cast<const void*>(&_t3)), const_cast<void*>(reinterpret_cast<const void*>(&_t4)), const_cast<void*>(reinterpret_cast<const void*>(&_t5)) };
    QMetaObject::activate(this, &staticMetaObject, 3, _a);
}
struct qt_meta_stringdata_octave__MessageDialog_t {
    QByteArrayData data[1];
    char stringdata0[22];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_octave__MessageDialog_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_octave__MessageDialog_t qt_meta_stringdata_octave__MessageDialog = {
    {
QT_MOC_LITERAL(0, 0, 21) // "octave::MessageDialog"

    },
    "octave::MessageDialog"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_octave__MessageDialog[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       0,    0, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

       0        // eod
};

void octave::MessageDialog::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    Q_UNUSED(_o);
    Q_UNUSED(_id);
    Q_UNUSED(_c);
    Q_UNUSED(_a);
}

const QMetaObject octave::MessageDialog::staticMetaObject = {
    { &QMessageBox::staticMetaObject, qt_meta_stringdata_octave__MessageDialog.data,
      qt_meta_data_octave__MessageDialog,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *octave::MessageDialog::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *octave::MessageDialog::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_octave__MessageDialog.stringdata0))
        return static_cast<void*>(this);
    return QMessageBox::qt_metacast(_clname);
}

int octave::MessageDialog::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QMessageBox::qt_metacall(_c, _id, _a);
    return _id;
}
struct qt_meta_stringdata_octave__ListDialog_t {
    QByteArrayData data[8];
    char stringdata0[111];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_octave__ListDialog_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_octave__ListDialog_t qt_meta_stringdata_octave__ListDialog = {
    {
QT_MOC_LITERAL(0, 0, 18), // "octave::ListDialog"
QT_MOC_LITERAL(1, 19, 16), // "finish_selection"
QT_MOC_LITERAL(2, 36, 0), // ""
QT_MOC_LITERAL(3, 37, 8), // "QIntList"
QT_MOC_LITERAL(4, 46, 16), // "buttonOk_clicked"
QT_MOC_LITERAL(5, 63, 20), // "buttonCancel_clicked"
QT_MOC_LITERAL(6, 84, 6), // "reject"
QT_MOC_LITERAL(7, 91, 19) // "item_double_clicked"

    },
    "octave::ListDialog\0finish_selection\0"
    "\0QIntList\0buttonOk_clicked\0"
    "buttonCancel_clicked\0reject\0"
    "item_double_clicked"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_octave__ListDialog[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       5,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       1,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    2,   39,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       4,    0,   44,    2, 0x0a /* Public */,
       5,    0,   45,    2, 0x0a /* Public */,
       6,    0,   46,    2, 0x0a /* Public */,
       7,    1,   47,    2, 0x0a /* Public */,

 // signals: parameters
    QMetaType::Void, 0x80000000 | 3, QMetaType::Int,    2,    2,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QModelIndex,    2,

       0        // eod
};

void octave::ListDialog::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        ListDialog *_t = static_cast<ListDialog *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->finish_selection((*reinterpret_cast< const QIntList(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2]))); break;
        case 1: _t->buttonOk_clicked(); break;
        case 2: _t->buttonCancel_clicked(); break;
        case 3: _t->reject(); break;
        case 4: _t->item_double_clicked((*reinterpret_cast< const QModelIndex(*)>(_a[1]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            typedef void (ListDialog::*_t)(const QIntList & , int );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&ListDialog::finish_selection)) {
                *result = 0;
                return;
            }
        }
    }
}

const QMetaObject octave::ListDialog::staticMetaObject = {
    { &QDialog::staticMetaObject, qt_meta_stringdata_octave__ListDialog.data,
      qt_meta_data_octave__ListDialog,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *octave::ListDialog::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *octave::ListDialog::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_octave__ListDialog.stringdata0))
        return static_cast<void*>(this);
    return QDialog::qt_metacast(_clname);
}

int octave::ListDialog::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDialog::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 5)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 5;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 5)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 5;
    }
    return _id;
}

// SIGNAL 0
void octave::ListDialog::finish_selection(const QIntList & _t1, int _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}
struct qt_meta_stringdata_octave__InputDialog_t {
    QByteArrayData data[6];
    char stringdata0[79];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_octave__InputDialog_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_octave__InputDialog_t qt_meta_stringdata_octave__InputDialog = {
    {
QT_MOC_LITERAL(0, 0, 19), // "octave::InputDialog"
QT_MOC_LITERAL(1, 20, 12), // "finish_input"
QT_MOC_LITERAL(2, 33, 0), // ""
QT_MOC_LITERAL(3, 34, 16), // "buttonOk_clicked"
QT_MOC_LITERAL(4, 51, 20), // "buttonCancel_clicked"
QT_MOC_LITERAL(5, 72, 6) // "reject"

    },
    "octave::InputDialog\0finish_input\0\0"
    "buttonOk_clicked\0buttonCancel_clicked\0"
    "reject"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_octave__InputDialog[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       4,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       1,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    2,   34,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       3,    0,   39,    2, 0x0a /* Public */,
       4,    0,   40,    2, 0x0a /* Public */,
       5,    0,   41,    2, 0x0a /* Public */,

 // signals: parameters
    QMetaType::Void, QMetaType::QStringList, QMetaType::Int,    2,    2,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,

       0        // eod
};

void octave::InputDialog::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        InputDialog *_t = static_cast<InputDialog *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->finish_input((*reinterpret_cast< const QStringList(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2]))); break;
        case 1: _t->buttonOk_clicked(); break;
        case 2: _t->buttonCancel_clicked(); break;
        case 3: _t->reject(); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            typedef void (InputDialog::*_t)(const QStringList & , int );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&InputDialog::finish_input)) {
                *result = 0;
                return;
            }
        }
    }
}

const QMetaObject octave::InputDialog::staticMetaObject = {
    { &QDialog::staticMetaObject, qt_meta_stringdata_octave__InputDialog.data,
      qt_meta_data_octave__InputDialog,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *octave::InputDialog::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *octave::InputDialog::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_octave__InputDialog.stringdata0))
        return static_cast<void*>(this);
    return QDialog::qt_metacast(_clname);
}

int octave::InputDialog::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDialog::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 4)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 4;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 4)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 4;
    }
    return _id;
}

// SIGNAL 0
void octave::InputDialog::finish_input(const QStringList & _t1, int _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}
struct qt_meta_stringdata_octave__FileDialog_t {
    QByteArrayData data[5];
    char stringdata0[65];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_octave__FileDialog_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_octave__FileDialog_t qt_meta_stringdata_octave__FileDialog = {
    {
QT_MOC_LITERAL(0, 0, 18), // "octave::FileDialog"
QT_MOC_LITERAL(1, 19, 12), // "finish_input"
QT_MOC_LITERAL(2, 32, 0), // ""
QT_MOC_LITERAL(3, 33, 15), // "acceptSelection"
QT_MOC_LITERAL(4, 49, 15) // "rejectSelection"

    },
    "octave::FileDialog\0finish_input\0\0"
    "acceptSelection\0rejectSelection"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_octave__FileDialog[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       3,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       1,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    3,   29,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       3,    0,   36,    2, 0x08 /* Private */,
       4,    0,   37,    2, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void, QMetaType::QStringList, QMetaType::QString, QMetaType::Int,    2,    2,    2,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void,

       0        // eod
};

void octave::FileDialog::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        FileDialog *_t = static_cast<FileDialog *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->finish_input((*reinterpret_cast< const QStringList(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2])),(*reinterpret_cast< int(*)>(_a[3]))); break;
        case 1: _t->acceptSelection(); break;
        case 2: _t->rejectSelection(); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            typedef void (FileDialog::*_t)(const QStringList & , const QString & , int );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&FileDialog::finish_input)) {
                *result = 0;
                return;
            }
        }
    }
}

const QMetaObject octave::FileDialog::staticMetaObject = {
    { &QFileDialog::staticMetaObject, qt_meta_stringdata_octave__FileDialog.data,
      qt_meta_data_octave__FileDialog,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *octave::FileDialog::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *octave::FileDialog::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_octave__FileDialog.stringdata0))
        return static_cast<void*>(this);
    return QFileDialog::qt_metacast(_clname);
}

int octave::FileDialog::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QFileDialog::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 3)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 3;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 3)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 3;
    }
    return _id;
}

// SIGNAL 0
void octave::FileDialog::finish_input(const QStringList & _t1, const QString & _t2, int _t3)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)), const_cast<void*>(reinterpret_cast<const void*>(&_t3)) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
